@@ -9,6 +9,8 @@ use POSIX qw(ceil);
 use Carp;
 use Tie::Hash::LRU;
 
+our $VERSION = '2.61';    ## VERSION
+
 our %popular;
 our $lru = tie %popular, 'Tie::Hash::LRU', 100;
 
@@ -20,14 +22,8 @@ Time::Duration::Concise
 
 Time::Duration::Concise is an improved approach to convert concise time duration to string representation.
 
-=head1 VERSION
-
-Version 1.3
-
 =cut
 
-our $VERSION = '1.3';
-
 our %LENGTH_TO_PERIOD = (
     86400 => 'day',
     3600  => 'hour',
@@ -55,9 +51,9 @@ our $KNOWN_UNITS_ = 'dhms';
     );
 
     # Intervals can have decimal values
-    1.5h etc
+    # 1.5h etc
 
-    my $duration = Time::Duration::Concise->new(
+    $duration = Time::Duration::Concise->new(
         interval => '1.5h'
     );
 
@@ -114,16 +110,16 @@ sub seconds {
     my $seconds = 0;
 
     # These should be integers, but we might need to have 0.5m
-    while ( $interval =~ s/([+-]?\d*\.?\d+)([$known_units])// ) {
+    while ($interval =~ s/([+-]?\d*\.?\d+)([$known_units])//) {
         my $amount = $1;
         my $units  = $2;
         $seconds += $amount * $PERIOD_SIZES{$units};
     }
 
-    if ( $interval ne '' ) {
+    if ($interval ne '') {
 
- # We had something which didn't match the above, which renders this unparseable
-        Carp::croak( "Bad format supplied [" . $interval . "]: unknown key." );
+        # We had something which didn't match the above, which renders this unparseable
+        Carp::croak("Bad format supplied [" . $interval . "]: unknown key.");
     }
     $self->{'_seconds'} = int $seconds;
     return $self->{'_seconds'};
@@ -191,9 +187,9 @@ Concise time druation to string representation.
 =cut
 
 sub as_string {
-    my ( $self, $precision ) = @_;
+    my ($self, $precision) = @_;
     my $time_frames = $self->_duration_array($precision);
-    return join( ' ', @$time_frames );
+    return join(' ', @$time_frames);
 }
 
 =head2 as_concise_string
@@ -203,16 +199,15 @@ Concise time druation to conscise string representation.
 =cut
 
 sub as_concise_string {
-    my ( $self, $precision ) = @_;
+    my ($self, $precision) = @_;
     $precision ||= 10;
     my $time_frames         = $self->_duration_array($precision);
     my @concise_time_frames = map {
-        $_ =~ s/\s+//ig;
-        $_ =~ /([-|\+]?\d+[A-Za-z]{1})/ig;
+        s/\s+//rg =~ /([-|\+]?\d+[A-Za-z]{1})/ig;
         $1;
     } @$time_frames;
     $self->{"_duration_array_$precision"} = undef;
-    return join( '', @concise_time_frames );
+    return join('', @concise_time_frames);
 }
 
 =head2 normalized_code
@@ -226,9 +221,9 @@ sub normalized_code {
     my @keys = sort @KNOWN_UNITS;
 
     my $entry_code = '0s';
-    while ( $entry_code eq '0s' and my $period = shift @keys ) {
+    while ($entry_code eq '0s' and my $period = shift @keys) {
         my $period_length = $PERIOD_SIZES{$period};
-        if ( not $self->seconds % $period_length ) {
+        if (not $self->seconds % $period_length) {
             my $period_size = $self->seconds / $period_length;
             $entry_code = $period_size . $period;
         }
@@ -245,36 +240,34 @@ Concise time druation to array
 =cut
 
 sub duration_array {
-    my ( $self, $precision ) = @_;
+    my ($self, $precision) = @_;
     my $durations = $self->_duration_array($precision);
     my @duration_distribution;
     foreach my $d (@$durations) {
-        my @d_value_unit = split( ' ', $d );
+        my @d_value_unit = split(' ', $d);
         push(
             @duration_distribution,
             {
                 'value' => $d_value_unit[0],
-                'unit'  => $d_value_unit[1]
-            }
-        );
+                'unit'  => $d_value_unit[1]});
     }
     return \@duration_distribution;
 }
 
 sub _duration_array {
-    my ( $self, $precision ) = @_;
+    my ($self, $precision) = @_;
 
     $precision ||= 10;
 
     return $self->{"_duration_array_$precision"}
-      if $self->{"_duration_array_$precision"};
+        if $self->{"_duration_array_$precision"};
 
     my $pretty_format = $self->duration->{'time'}->pretty;
     $pretty_format =~ s/minus /-/ig;
 
     my @time_frame;
     my $precision_counter = 1;
-    foreach my $frame ( split( ',', $pretty_format ) ) {
+    foreach my $frame (split(',', $pretty_format)) {
         next if $precision_counter > $precision;
         chomp $frame;
         $frame =~ s/^\s+|\s+$//g;
@@ -284,7 +277,7 @@ sub _duration_array {
         # Make sure we gets the number
         # to avoid Use of uninitialized warning
         my $value = $1;
-        if ( defined $value && $value ) {
+        if (defined $value && $value) {
 
             $value =~ s/\s+//ig;
 
@@ -292,13 +285,13 @@ sub _duration_array {
             $frame .= 's' if $value > 1;
 
             if ($frame) {
-                push( @time_frame, $frame );
+                push(@time_frame, $frame);
                 $precision_counter++;
             }
         }
     }
-    if ( !scalar @time_frame ) {
-        push( @time_frame, '0 second' );
+    if (!scalar @time_frame) {
+        push(@time_frame, '0 second');
     }
     $self->{"_duration_array_$precision"} = \@time_frame;
     return \@time_frame;
@@ -311,7 +304,7 @@ Shorthand to call time methods
 =cut
 
 sub multiple_units_of {
-    my ( $self, $unit ) = @_;
+    my ($self, $unit) = @_;
     # two is multiple!
     return ($self->_minimum_number_of($unit) >= 2) ? 1 : 0;
 }
@@ -323,15 +316,15 @@ Returns the minimum number of the given period.
 =cut
 
 sub minimum_number_of {
-    my ( $self, $unit ) = @_;
-    return ceil( $self->_minimum_number_of($unit) );
+    my ($self, $unit) = @_;
+    return ceil($self->_minimum_number_of($unit));
 }
 
 sub _minimum_number_of {
-    my ( $self, $unit ) = @_;
+    my ($self, $unit) = @_;
     my $orig_unit = $unit;
-    $unit =~ s/s$// if ( length($unit) > 1 ); # Chop plurals, but not 's' itself
-    $unit = substr( $unit, 0, 1 );
+    $unit =~ s/s$// if (length($unit) > 1);    # Chop plurals, but not 's' itself
+    $unit = substr($unit, 0, 1);
     $unit = 'mo' if $orig_unit =~ /^months|^mo/ig;
 
     my %unit_maps = (
@@ -366,7 +359,7 @@ Returns HASH of duration with the following keys
 sub duration {
     my ($self) = @_;
     return $self->{'_duration'} if $self->{'_duration'};
-    my $time_    = Time::Seconds->new( $self->seconds );
+    my $time_    = Time::Seconds->new($self->seconds);
     my $duration = {
         'time'    => $time_,
         'years'   => $time_->years,
@@ -405,35 +398,36 @@ Object constructor
 
 =cut
 
-sub new {
+sub new {    ## no critic (RequireArgUnpacking)
     my $class = shift;
-    my %params_ref = ref( $_[0] ) ? %{ $_[0] } : @_;
+    my %params_ref = ref($_[0]) ? %{$_[0]} : @_;
 
     my $interval = $params_ref{'interval'};
 
     confess "Missing required arguments"
-      unless defined $interval;
+        unless defined $interval;
 
-    if ( $popular{$interval} ) {
+    if ($popular{$interval}) {
         ## Helps in multiple calling, it would really save the time
         return $popular{$interval};
     }
 
-    if ( defined $interval ) {
+    if (defined $interval) {
         Carp::croak("Invalid time interval") if $interval eq '';
     }
-    my $known_units = $KNOWN_UNITS_;
 
     # Try our best to make it parseable.
     $interval =~ s/\s//g;
     $interval = lc $interval;
 
     # All numbers implies a number of seconds.
-    if ( $interval !~ /[A-Za-z]/ ) {
+    if ($interval !~ /[A-Za-z]/) {
         $interval .= 's';
     }
 
-    my $self = { _interval => $interval, };
+    my $self = {
+        _interval => $interval,
+    };
     my $obj = bless $self, $class;
     $popular{$interval} = $obj;
     return $obj;
@@ -478,47 +472,6 @@ L<http://search.cpan.org/dist/Time-Duration-Concise-Localize/>
 
 =back
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2014 Binary.com.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-
 =cut
 
 1;    # End of Time::Duration::Concise
