@@ -8,11 +8,11 @@ use utf8;
 use Carp;
 use base qw(Time::Duration::Concise);
 use Module::Pluggable
-  search_path => 'Time::Duration::Concise::Locale',
-  sub_name    => 'translation_classes',
-  require     => 1;
+    search_path => 'Time::Duration::Concise::Locale',
+    sub_name    => 'translation_classes',
+    require     => 1;
 
-our $VERSION = '2.6';
+our $VERSION = '2.61';
 
 =head1 NAME
 
@@ -22,10 +22,6 @@ Time::Duration::Concise::Localize - localize concise time duration string repres
 
 Time::Duration::Concise provides localize concise time duration string representation.
 
-=head1 VERSION
-
-Version 2.6
-
 =head1 SYNOPSIS
 
     use Time::Duration::Concise::Localize;
@@ -54,7 +50,7 @@ Get and set the locale for translation
 =cut
 
 sub locale {
-    my ( $self, $locale ) = @_;
+    my ($self, $locale) = @_;
     $self->{'locale'} = lc $locale if $locale;
     return $self->{'locale'};
 }
@@ -103,9 +99,9 @@ Object constructor
 
 =cut
 
-sub new {
+sub new {    ## no critic (RequireArgUnpacking)
     my $class = shift;
-    my %params_ref = ref( $_[0] ) ? %{ $_[0] } : @_;
+    my %params_ref = ref($_[0]) ? %{$_[0]} : @_;
 
     my $interval = $params_ref{'interval'};
 
@@ -119,11 +115,11 @@ sub new {
         confess "Missing required arguments";
     }
 
-    my $self = $class->SUPER::new( interval => $interval );
+    my $self = $class->SUPER::new(interval => $interval);
 
     # Set default locale as english
     $self->{'locale'} = 'en';
-    if ( exists $params_ref{'locale'} ) {
+    if (exists $params_ref{'locale'}) {
         $self->{'locale'} = lc $params_ref{'locale'};
     }
 
@@ -170,48 +166,6 @@ L<http://search.cpan.org/dist/Time-Duration-Concise-Localize/>
 
 =back
 
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2014 Binary.com.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-
 =cut
 
 1;    # End of Time::Duration::Concise::Localize
